@@ -3,10 +3,12 @@
 #' Retrieves names of installed packages by calling \code{\link[utils]{installed.packages}} and returning only those packages where \code{Priority} equals "base".
 #' 
 #' @export
-#' @seealso pkgDeps
+#' @family miniCRAN functions
+#' @seealso \code{\link{pkgDep}}
 basePkgs <- function()names(which(installed.packages()[, "Priority"] == "base"))
 
 
+
 #' Retrieves package dependencies.
 #' 
 #' Performs recursive retrieve for \code{Depends}, \code{Imports} and \code{LinkLibrary}. Performs non-recursive retrieve for \code{Suggests}.
@@ -16,21 +18,20 @@ basePkgs <- function()names(which(installed.packages()[, "Priority"] == "base"))
 #' @param pkg Character vector of packages.
 #' @param availPkgs Vector of available packages.  Defaults to reading this list from CRAN, using \code{\link{available.packages}}
 #' @param repos URL(s) of the 'contrib' sections of the repositories. Passed to \code{\link{available.packages}}
-#' @param type Passed to \code{\link{available.packages}}
+#' @param type Possible values are (currently) "source", "mac.binary" and "win.binary": the binary types can be listed and downloaded but not installed on other platforms.  Passed to \code{\link{download.packages}}.
 #' @param depends If TRUE, retrieves Depends, Imports and LinkingTo dependencies (non-recursively)
 #' @param suggests If TRUE, retrieves Suggests dependencies (non-recursively)
 #' @param enhances If TRUE, retrieves Enhances dependencies (non-recursively)
-#' @param path Destination download path
 #' @param includeBasePkgs If TRUE, include base R packages in results
 #' @param ... Other arguments passed to \code{\link{available.packages}}
 #' 
 #' @export
-#' @seealso makeDepGraph
-#' @family miniCRAN
+#' @seealso \code{\link{makeDepGraph}}
+#' @family miniCRAN functions
 #' 
-#' @example /inst/examples/example-pkgDep.R
+#' @example \inst\examples\example_pkgDep.R
 
-pkgDep <- function(pkg, availPkgs, repos=getOption("repos"), type="source", depends=TRUE, suggests=TRUE, enhances=FALSE, path, includeBasePkgs=FALSE, ...){
+pkgDep <- function(pkg, availPkgs, repos=getOption("repos"), type="source", depends=TRUE, suggests=TRUE, enhances=FALSE, includeBasePkgs=FALSE, ...){
   if(!depends & !suggests & !enhances) {
     warning("Returning nothing, since depends, suggests and enhances are all FALSE")
     return(character(0))
@@ -44,7 +45,7 @@ pkgDep <- function(pkg, availPkgs, repos=getOption("repos"), type="source", depe
       repos <- c(CRAN="http://cran.revolutionanalytics.com")
     }
     if(is.na(type)) type <- "source"
-    availPkgs <- pkgAvail(path=path, repos=repos, type=type, ...)
+    availPkgs <- pkgAvail(repos=repos, type=type, ...)
   }
   if(nrow(availPkgs) == 0){
     stop("Unable to retrieve available packages from CRAN")
@@ -114,11 +115,12 @@ print.pkgDep <- function(x, ...){
 
 #' Reads available packages from CRAN repository.
 #' 
-#' This is a thin wrapper around \code{\link{available.packages}}.  If the argument \code{path} is supplied, then the function attempts to read from a local repository, otherwise attempts to read from a CRAN mirror at the \code{repos} url.
+#' This is a thin wrapper around \code{\link[utils]{available.packages}}.  If the argument \code{path} is supplied, then the function attempts to read from a local repository, otherwise attempts to read from a CRAN mirror at the \code{repos} url.
 #' 
 #' @inheritParams pkgDep
 #' @export
-#' @family miniCRAN
+#' @family miniCRAN functions
+#' @seealso \code{\link{pkgDep}}
 pkgAvail <- function(repos=getOption("repos"), type="source", ...){
   if(!grepl("^file", repos[1]) && file.exists(repos[1])) {
     repos <- paste0("file:///", repos[1])
